@@ -13,10 +13,9 @@
 
 #include <QPushButton>
 
-#include <KStandardGuiItem>
 #include <KLocalizedString>
+#include <KStandardGuiItem>
 
-#include <BluezQt/Device>
 #include <BluezQt/Adapter>
 #include <BluezQt/PendingCall>
 
@@ -58,7 +57,7 @@ void PairingPage::initializePage()
     connectingLbl->show();
     confirmLbl->clear();
 
-    connectingLbl->setText(i18n("Connecting to %1...", m_device->name()));
+    connectingLbl->setText(i18n("Connecting to %1…", m_device->name()));
 
     connect(m_wizard->agent(), &WizardAgent::pinRequested, this, &PairingPage::pinRequested);
     connect(m_wizard->agent(), &WizardAgent::confirmationRequested, this, &PairingPage::confirmationRequested);
@@ -70,7 +69,7 @@ void PairingPage::initializePage()
 void PairingPage::pairingFinished(BluezQt::PendingCall *call)
 {
     qCDebug(WIZARD) << "Pairing finished:";
-    qCDebug(WIZARD) << "\t error     : " << (bool) call->error();
+    qCDebug(WIZARD) << "\t error     : " << (bool)call->error();
     qCDebug(WIZARD) << "\t errorText : " << call->errorText();
 
     m_success = !call->error();
@@ -121,7 +120,7 @@ void PairingPage::confirmationRequested(const QString &passkey, const BluezQt::R
     m_wizard->setButton(QWizard::CustomButton1, matches);
     m_wizard->setButton(QWizard::CustomButton2, notMatch);
 
-    QList <QWizard::WizardButton> list;
+    QList<QWizard::WizardButton> list;
     list << QWizard::Stretch;
     list << QWizard::CustomButton1;
     list << QWizard::CustomButton2;
@@ -153,7 +152,7 @@ void PairingPage::cancelClicked()
 
 QList<QWizard::WizardButton> PairingPage::wizardButtonsLayout() const
 {
-    QList <QWizard::WizardButton> list;
+    QList<QWizard::WizardButton> list;
     list << QWizard::Stretch;
     list << QWizard::CustomButton1;
     return list;
